summaryrefslogtreecommitdiff
path: root/lib/CodeGen/AsmPrinter/DwarfUnit.h
diff options
context:
space:
mode:
authorDavid Blaikie <dblaikie@gmail.com>2013-12-02 22:09:48 +0000
committerDavid Blaikie <dblaikie@gmail.com>2013-12-02 22:09:48 +0000
commit451fa97c8c74837ef2eab10f79e7145ad25e260d (patch)
treef8812fc53287f59438670d21bfc1047d9bf671d1 /lib/CodeGen/AsmPrinter/DwarfUnit.h
parent7d318bd116762312db60fec32630ee9d02e81d0d (diff)
downloadllvm-451fa97c8c74837ef2eab10f79e7145ad25e260d.tar.gz
llvm-451fa97c8c74837ef2eab10f79e7145ad25e260d.tar.bz2
llvm-451fa97c8c74837ef2eab10f79e7145ad25e260d.tar.xz
DebugInfo: Rename generic unit references to "TheU" instead of TheCU now that they might be type units instead of compile units.
CR feedback from Eric Christopher on r196139. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@196159 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/CodeGen/AsmPrinter/DwarfUnit.h')
-rw-r--r--lib/CodeGen/AsmPrinter/DwarfUnit.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/CodeGen/AsmPrinter/DwarfUnit.h b/lib/CodeGen/AsmPrinter/DwarfUnit.h
index 080e21384a..0ee1aade64 100644
--- a/lib/CodeGen/AsmPrinter/DwarfUnit.h
+++ b/lib/CodeGen/AsmPrinter/DwarfUnit.h
@@ -42,10 +42,10 @@ protected:
/// Node - MDNode for the compile unit.
DICompileUnit Node;
- /// CUDie - Compile unit debug information entry.
- const OwningPtr<DIE> CUDie;
+ /// Unit debug information entry.
+ const OwningPtr<DIE> UnitDie;
- /// Offset of the CUDie from beginning of debug info section.
+ /// Offset of the UnitDie from beginning of debug info section.
unsigned DebugInfoOffset;
/// Asm - Target of Dwarf emission.
@@ -55,7 +55,7 @@ protected:
DwarfDebug *DD;
DwarfUnits *DU;
/// IndexTyDie - An anonymous type for index type. Owned by CUDie.
DIE *IndexTyDie;
/// MDNodeToDieMap - Tracks the mapping of unit level debug information
@@ -108,7 +108,7 @@ public:
unsigned getUniqueID() const { return UniqueID; }
virtual uint16_t getLanguage() const = 0;
DICompileUnit getNode() const { return Node; }
- DIE *getCUDie() const { return CUDie.get(); }
+ DIE *getUnitDie() const { return UnitDie.get(); }
const StringMap<const DIE *> &getGlobalNames() const { return GlobalNames; }
const StringMap<const DIE *> &getGlobalTypes() const { return GlobalTypes; }
@@ -130,7 +130,7 @@ public:
void setDebugInfoOffset(unsigned DbgInfoOff) { DebugInfoOffset = DbgInfoOff; }
/// hasContent - Return true if this compile unit has something to write out.
- bool hasContent() const { return !CUDie->getChildren().empty(); }
+ bool hasContent() const { return !UnitDie->getChildren().empty(); }
/// getParentContextString - Get a string containing the language specific
/// context for a global name.
@@ -170,7 +170,7 @@ public:
/// addDie - Adds or interns the DIE to the compile unit.
///
- void addDie(DIE *Buffer) { CUDie->addChild(Buffer); }
+ void addDie(DIE *Buffer) { UnitDie->addChild(Buffer); }
/// addFlag - Add a flag that is true to the DIE.
void addFlag(DIE *Die, dwarf::Attribute Attribute);
@@ -55,7 +55,7 @@ protected:
DwarfDebug *DD;
DwarfUnits *DU;
- /// IndexTyDie - An anonymous type for index type. Owned by CUDie.
+ /// IndexTyDie - An anonymous type for index type. Owned by UnitDie.
DIE *IndexTyDie;
/// MDNodeToDieMap - Tracks the mapping of unit level debug information